@@ -1,3 +1,4 @@
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
@@ -31,33 +32,33 @@
 
 from __future__ import absolute_import
 
-from typing import Dict, Optional, List
+from typing import Dict, List, Optional
 
 from univention.listener import ListenerModuleHandler
 
 
 class ListenerModuleTemplate(ListenerModuleHandler):
 
-	class Configuration(object):
-		name = 'unique_name'
-		description = 'listener module description'
-		ldap_filter = '(&(objectClass=inetOrgPerson)(uid=example))'
-		attributes = ['sn', 'givenName']
+    class Configuration(object):
+        name = 'unique_name'
+        description = 'listener module description'
+        ldap_filter = '(&(objectClass=inetOrgPerson)(uid=example))'
+        attributes = ['sn', 'givenName']
 
-	def create(self, dn: str, new: Dict[str, List[bytes]]) -> None:
-		self.logger.debug('dn: %r', dn)
+    def create(self, dn: str, new: Dict[str, List[bytes]]) -> None:
+        self.logger.debug('dn: %r', dn)
 
-	def modify(
-		self,
-		dn: str,
-		old: Dict[str, List[bytes]],
-		new: Dict[str, List[bytes]],
-		old_dn: Optional[str],
-	) -> None:
-		self.logger.debug('dn: %r', dn)
-		if old_dn:
-			self.logger.debug('it is (also) a move! old_dn: %r', old_dn)
-		self.logger.debug('changed attributes: %r', self.diff(old, new))
+    def modify(
+            self,
+            dn: str,
+            old: Dict[str, List[bytes]],
+            new: Dict[str, List[bytes]],
+            old_dn: Optional[str],
+    ) -> None:
+        self.logger.debug('dn: %r', dn)
+        if old_dn:
+            self.logger.debug('it is (also) a move! old_dn: %r', old_dn)
+        self.logger.debug('changed attributes: %r', self.diff(old, new))
 
-	def remove(self, dn: str, old: Dict[str, List[bytes]]) -> None:
-		self.logger.debug('dn: %r', dn)
+    def remove(self, dn: str, old: Dict[str, List[bytes]]) -> None:
+        self.logger.debug('dn: %r', dn)
